@@ -18,18 +18,19 @@ require AutoLoader;
 # Do not simply export all your public functions/methods/constants.
 @EXPORT =
   qw(
-      Success Transparent Opaque MaxRGB WarningException
-      ResourceLimitWarning TypeWarning OptionWarning DelegateWarning
-      MissingDelegateWarning CorruptImageWarning FileOpenWarning
-      BlobWarning StreamWarning CacheWarning XServerWarning
-      RegistryWarning ConfigureWarning ErrorException
-      ResourceLimitError TypeError OptionError DelegateError
-      MissingDelegateError CorruptImageError FileOpenError BlobError
-      StreamError CacheError XServerError RegistryError ConfigureError
-      FatalErrorException
+      Success Transparent Opaque QuantumDepth QuantumRange MaxRGB
+      WarningException ResourceLimitWarning TypeWarning OptionWarning
+      DelegateWarning MissingDelegateWarning CorruptImageWarning
+      FileOpenWarning BlobWarning StreamWarning CacheWarning CoderWarning
+      ModuleWarning DrawWarning ImageWarning XServerWarning RegistryWarning
+      ConfigureWarning ErrorException ResourceLimitError TypeError
+      OptionError DelegateError MissingDelegateError CorruptImageError
+      FileOpenError BlobError StreamError CacheError CoderError
+      ModuleError DrawError ImageError XServerError RegistryError
+      ConfigureError FatalErrorException
     );
 
-$VERSION = '5.49';
+$VERSION = '6.2.9';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -84,33 +85,32 @@ __END__
 
 =head1 NAME
 
-Image::Magick - Perl extension for calling ImageMagick's libmagick routines
+Image::Magick - Perl extension for calling ImageMagick's libMagick methods
 
 =head1 SYNOPSIS
 
   use Image::Magick;
-  p = new Image::Magick;
-  p->Read("imagefile");
-  p->Set(attribute => value, ...)
-  ($a, ...) = p->Get("attribute", ...)
-  p->routine(parameter => value, ...)
-  p->Mogrify("Routine", parameter => value, ...)
-  p->Write("filename");
+  $p = new Image::Magick;
+  $p->Read("imagefile");
+  $p->Set(attribute => value, ...)
+  ($a, ...) = $p->Get("attribute", ...)
+  $p->routine(parameter => value, ...)
+  $p->Mogrify("Routine", parameter => value, ...)
+  $p->Write("filename");
 
 =head1 DESCRIPTION
 
 This Perl extension allows the reading, manipulation and writing of
-a large number of image file formats using the magick library from
-ImageMagick by John Cristy (magick@wizards.dupont.com).  It was originally
-developed to be used by CGI scripts for Web pages.
+a large number of image file formats using the ImageMagick library.
+It was originally developed to be used by CGI scripts for Web pages.
 
 A Web page has been set up for this extension. See:
 
-	http://www.simplesystems.org/ImageMagick/www/perl.html
+	http://www.imagemagick.org/script/perl-magick.php
 
 =head1 AUTHOR
 
-Kyle Shorter	magick@wizards.dupont.com
+Kyle Shorter	magick-users@imagemagick.org
 
 =head1 BUGS
 
