@@ -1,4 +1,4 @@
-#!/usr/local/bin/perl
+#!/usr/bin/perl
 #
 # Overall demo of the major PerlMagick methods.
 #
@@ -17,34 +17,47 @@ $model=Image::Magick->new();
 $x=$model->ReadImage('model.gif');
 warn "$x" if "$x";
 $model->Label('Magick');
-$model->Set(bordercolor=>'black');
-$model->Set(background=>'black');
+$model->Set(background=>'white');
 
 $smile=Image::Magick->new;
 $x=$smile->ReadImage('smile.gif');
 warn "$x" if "$x";
 $smile->Label('Smile');
-$smile->Set(bordercolor=>'black');
+$smile->Set(background=>'white');
 #
 # Create image stack.
 #
 print "Transform image...\n";
 $images=Image::Magick->new();
-$example=$null->Clone();
+
+print "Adaptive Blur...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Blur');
+$example->AdaptiveBlur('0x1');
 push(@$images,$example);
-$example=$null->Clone();
+
+print "Adaptive Resize...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Resize');
+$example->AdaptiveResize('60%');
 push(@$images,$example);
-$example=$null->Clone();
+
+print "Adaptive Sharpen...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Sharpen');
+$example->AdaptiveSharpen('0x1');
 push(@$images,$example);
-$example=$null->Clone();
-push(@$images,$example);
-$example=$null->Clone();
+
+print "Adaptive Threshold...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Threshold');
+$example->AdaptiveThreshold('5x5+5%');
 push(@$images,$example);
 
 print "Add Noise...\n";
 $example=$model->Clone();
 $example->Label('Add Noise');
-$example->AddNoise("LaplacianNoise");
+$example->AddNoise("Laplacian");
 push(@$images,$example);
 
 print "Annotate...\n";
@@ -69,13 +82,13 @@ push(@$images,$example);
 print "Channel...\n";
 $example=$model->Clone();
 $example->Label('Channel');
-$example->Channel();
+$example->Channel(channel=>'red');
 push(@$images,$example);
 
 print "Charcoal...\n";
 $example=$model->Clone();
 $example->Label('Charcoal');
-$example->Charcoal();
+$example->Charcoal('0x1');
 push(@$images,$example);
 
 print "Composite...\n";
@@ -90,6 +103,12 @@ $example->Label('Contrast');
 $example->Contrast();
 push(@$images,$example);
 
+print "Contrast Stretch...\n";
+$example=$model->Clone();
+$example->Label('Contrast Stretch');
+$example->ContrastStretch('5%');
+
+push(@$images,$example);
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
@@ -100,6 +119,7 @@ print "Crop...\n";
 $example=$model->Clone();
 $example->Label('Crop');
 $example->Crop(geometry=>'80x80+25+50');
+$example->Set(page=>'0x0+0+0');
 push(@$images,$example);
 
 print "Despeckle...\n";
@@ -124,10 +144,10 @@ push(@$images,$example);
 print "Emboss...\n";
 $example=$model->Clone();
 $example->Label('Emboss');
-$example->Emboss();
+$example->Emboss('0x1');
+push(@$images,$example);
 
 print "Equalize...\n";
-push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Equalize');
 $example->Equalize();
@@ -136,7 +156,6 @@ push(@$images,$example);
 print "Implode...\n";
 $example=$model->Clone();
 $example->Label('Explode');
-$example->Set(background=>'#000000FF');
 $example->Implode(-1);
 push(@$images,$example);
 
@@ -158,6 +177,11 @@ $example->Label('Frame');
 $example->Frame('15x15+3+3');
 push(@$images,$example);
 
+print "Fx...\n";
+$example=$model->Clone();
+$example->Label('Fx');
+push(@$images,$example->Fx(expression=>'0.5*u'));
+
 print "Gamma...\n";
 $example=$model->Clone();
 $example->Label('Gamma');
@@ -190,6 +214,12 @@ $example->Label('Implode');
 $example->Implode(0.5);
 push(@$images,$example);
 
+print "Level...\n";
+$example=$model->Clone();
+$example->Label('Level');
+$example->Level(level=>'20%');
+push(@$images,$example);
+
 print "Median Filter...\n";
 $example=$model->Clone();
 $example->Label('Median Filter');
@@ -208,6 +238,12 @@ $example->Label('Monochrome');
 $example->Quantize(colorspace=>'gray',colors=>2,dither=>'false');
 push(@$images,$example);
 
+print "Motion Blur...\n";
+$example=$model->Clone();
+$example->Label('Motion Blur');
+$example->MotionBlur('0x13+10-10');
+push(@$images,$example);
+
 print "Negate...\n";
 $example=$model->Clone();
 $example->Label('Negate');
@@ -240,6 +276,12 @@ $example->Label('Quantize');
 $example->Quantize();
 push(@$images,$example);
 
+print "Radial Blur...\n";
+$example=$model->Clone();
+$example->Label('Radial Blur');
+$example->RadialBlur(10);
+push(@$images,$example);
+
 print "Raise...\n";
 $example=$model->Clone();
 $example->Label('Raise');
@@ -255,7 +297,7 @@ push(@$images,$example);
 print "Resize...\n";
 $example=$model->Clone();
 $example->Label('Resize');
-$example->Resize('50%');
+$example->Resize('60%');
 push(@$images,$example);
 
 print "Roll...\n";
@@ -268,7 +310,12 @@ print "Rotate...\n";
 $example=$model->Clone();
 $example->Label('Rotate');
 $example->Rotate(45);
-$example->Transparent(color=>'black');
+push(@$images,$example);
+
+print "Sample...\n";
+$example=$model->Clone();
+$example->Label('Sample');
+$example->Sample('60%');
 push(@$images,$example);
 
 print "Scale...\n";
@@ -286,7 +333,7 @@ push(@$images,$example);
 print "Shade...\n";
 $example=$model->Clone();
 $example->Label('Shade');
-$example->Shade(geometry=>'30x30',color=>'false');
+$example->Shade(geometry=>'30x30',gray=>'true');
 push(@$images,$example);
 
 print "Sharpen...\n";
@@ -304,8 +351,13 @@ push(@$images,$example);
 print "Shear...\n";
 $example=$model->Clone();
 $example->Label('Shear');
-$example->Shear('45x45');
-$example->Transparent(color=>'black');
+$example->Shear('-20x20');
+push(@$images,$example);
+
+print "Sigmoidal Contrast...\n";
+$example=$model->Clone();
+$example->Label('Sigmoidal Contrast');
+$example->SigmoidalContrast("3x50%");
 push(@$images,$example);
 
 print "Spread...\n";
@@ -322,7 +374,6 @@ push(@$images,$example);
 
 print "Swirl...\n";
 $example=$model->Clone();
-$example->Set(background=>'#000000FF');
 $example->Label('Swirl');
 $example->Swirl(90);
 push(@$images,$example);
@@ -333,20 +384,24 @@ $example->Label('Unsharp Mask');
 $example->UnsharpMask('0.0x1.0');
 push(@$images,$example);
 
+print "Vignette...\n";
+$example=$model->Clone();
+$example->Label('Vignette');
+$example->Vignette('0x20');
+push(@$images,$example);
+
 print "Wave...\n";
 $example=$model->Clone();
 $example->Label('Wave');
-$example->Set(background=>'#000000FF');
 $example->Wave('25x150');
 push(@$images,$example);
 #
 # Create image montage.
 #
 print "Montage...\n";
-$montage=$images->Montage(geometry=>'130x194+10+5>',gravity=>'Center',
-  bordercolor=>'green',borderwidth=>1,tile=>'5x1000',compose=>'over',
-  background=>'#ffffff',font=>'Generic.ttf',pointsize=>18,fill=>'#600',
-  stroke=>'none');
+$montage=$images->Montage(geometry=>'128x160+8+4>',gravity=>'Center',
+  tile=>'5x+10+200',compose=>'over',background=>'#ffffff',
+  font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none');
 
 $logo=Image::Magick->new();
 $logo->Read('logo:');
